﻿Public Class Form1
    ' Modulszintű konstansok és változók:
    Const Maxkoord As Integer = 699         ' a rajzlap mérete 700x700 pixel
    Const OrigóX As Integer = Maxkoord \ 2  ' a rajzlap közepének x koordinátája
    Const OrigóY As Integer = Maxkoord \ 2  ' a rajzlap közepének y koordinátája
    Dim Rajz As Bitmap
    Dim Grafobj As Graphics
    Dim Toll As Pen
    Dim Ecset As SolidBrush

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' A rajzobjektum (rajzlap) létrehozása:
        Rajz = New Bitmap(Maxkoord, Maxkoord)
        ' A rajzot hozzárendeljük a képdobozhoz:
        PictureBox1.Image = Rajz
        ' A grafikaobjektum létrehozása és hozzárendelése a rajzobjektumhoz:
        Grafobj = Graphics.FromImage(Rajz)
        ' A toll és az ecset objektum létrehozása:
        Toll = New Pen(Color.Black, 1)
        '  (fekete színű, 1 pixel méretű)
        Ecset = New SolidBrush(Color.Blue)
        '  (kék kitöltőszín)
    End Sub

    Private Sub Pontfelhő_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Pontfelhő.Click
        Const X0 As Single = 10      ' a kezdőpont x koordinátája
        Const Y0 As Single = 10      ' a kezdőpont y koordinátája
        Const A As Single = 8        ' transzformációs paraméterek
        Const B As Single = 3
        Const C As Single = -4
        Const R As Single = 120
        Const MinD As Single = 3     ' a D paraméter minimális értéke
        Const MaxD As Single = 13    ' a D paraméter maximális értéke
        Const Db As Integer = 10000  ' a pontok száma egy ciklusban
        Dim X, Y, Xúj, Yúj As Single ' a pont koordinátái
        Dim D As Single              ' a D paraméter aktuális értéke
        Dim I As Integer             ' ciklusváltozó
        ' Töröljük a rajzlapot (kitöltjük fehér színnel):
        Grafobj.Clear(Color.White)
        X = X0
        Y = Y0
        ' Kiszámítjuk az új koordinátákat és megrajzoljuk a pontokat:
        For D = MinD To MaxD
            For I = 1 To Db
                Xúj = A * X + B * Y
                Yúj = C * X + D * Y
                X = Xúj * (R / Math.Sqrt(Xúj ^ 2 + Yúj ^ 2)) ^ 2
                Y = Yúj * (R / Math.Sqrt(Xúj ^ 2 + Yúj ^ 2)) ^ 2
                Rajz.SetPixel(X + OrigóX, Y + OrigóY, Color.Red)
            Next
        Next
        PictureBox1.Invalidate()
    End Sub

    Private Sub Mandelbrot_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Mandelbrot.Click
        Const MinX As Single = -1.7
        Const MaxX As Single = 0.5
        Const MinY As Single = -1
        Const MaxY As Single = 1
        Const MaxIsmétlés = 100
        Dim X0, Y0 As Single
        Dim X, Y, TempX As Single
        Dim Ismétlés As Integer
        Dim Szín As Color
        Grafobj.Clear(Color.Black)
        For X0 = MinX To MaxX Step 0.005
            For Y0 = MinY To MaxY Step 0.005
                X = 0
                Y = 0
                Ismétlés = 0
                Do While X ^ 2 + Y ^ 2 <= 4 And Ismétlés < MaxIsmétlés
                    TempX = X ^ 2 - Y ^ 2 + X0
                    Y = 2 * X * Y + Y0
                    X = TempX
                    Ismétlés += 1
                Loop
                If Ismétlés < MaxIsmétlés Then
                    Szín = Color.FromArgb(0, 0, 100 * Ismétlés / MaxIsmétlés + 155)
                    Rajz.SetPixel(X0 * 200 + OrigóX, Y0 * 200 + OrigóY, Szín)
                End If
            Next
        Next
        PictureBox1.Invalidate()
    End Sub

    Private Sub Szúnyog_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Szúnyog.Click
        Const Maxugrás As Integer = 10 ' a legnagyobb változás értéke
        Dim X, Y, Xúj, Yúj As Integer
        Dim Vélszám As Random
        Vélszám = New Random
        Grafobj.Clear(Color.White)
        Toll.Width = 1
        Toll.Color = Color.Blue
        X = OrigóX
        Y = OrigóY
        Do While X > 0 And X <= Maxkoord And Y > 0 And Y <= Maxkoord
            Xúj = X + Vélszám.Next(-Maxugrás, Maxugrás + 1)
            Yúj = Y + Vélszám.Next(-Maxugrás, Maxugrás + 1)
            Grafobj.DrawLine(Toll, X, Y, Xúj, Yúj)
            X = Xúj
            Y = Yúj
            ' Threading.Thread.Sleep(5) ' várakozás
            Me.Refresh()              ' képernyőfrissítés
        Loop
    End Sub

    Private Sub Szőnyeg_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Szőnyeg.Click
        Const MaxHossz As Double = 8
        Const MaxTáv As Double = 20
        Dim Kezd As Integer
        Dim X, Y, Hossz As Integer
        Dim Vélszám As Random
        Vélszám = New Random
        Grafobj.Clear(Color.White)
        Toll.Width = 1
        Toll.Color = Color.Blue
        X = 0
        Do While X < Maxkoord
            For Y = Maxkoord \ 4 To 3 * Maxkoord \ 4
                Kezd = X + MaxHossz * Vélszám.NextDouble
                Hossz = MaxHossz * Vélszám.NextDouble
                Grafobj.DrawLine(Toll, Kezd, Y, Kezd + Hossz, Y)
            Next
            X += MaxTáv * Vélszám.NextDouble
        Loop
        PictureBox1.Invalidate()
    End Sub

    Private Sub Interferencia_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Interferencia.Click
        Dim I, Lépésköz As Integer
        ' Töröljük a rajzlapot (kitöltjük fehér színnel):
        Grafobj.Clear(Color.White)
        ' Beállítjuk a Toll tulajdonságait:
        Toll.Width = 1
        Toll.Color = Color.Blue
        Lépésköz = InputBox("Add meg a lépésközt (1-100)!", "Lépésköz", "3")
        For I = 0 To Maxkoord Step Lépésköz
            Grafobj.DrawLine(Toll, 0, I, Maxkoord, Maxkoord - I)
            Grafobj.DrawLine(Toll, I, 0, Maxkoord - I, Maxkoord)
        Next
        PictureBox1.Invalidate()
    End Sub

    Private Sub Alagút_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Alagút.Click
        Const Minhossz As Integer = 30 ' a legkisebb téglalap oldala
        Const Dhossz As Single = 0.2   ' a legnagyobb méretcsökkenés mértéke
        Dim Hossz As Single
        Dim Vélszám As Random
        ' Töröljük a rajzlapot (kitöltjük fehér színnel):
        Grafobj.Clear(Color.White)
        ' Beállítjuk az Ecset színét:
        Ecset.Color = Color.Aqua
        Vélszám = New Random
        Hossz = Maxkoord
        Do While Hossz > Minhossz
            Grafobj.FillRectangle(Ecset, OrigóX - Hossz / 2, OrigóY - Hossz / 4, Hossz, Hossz / 2)
            Hossz -= Hossz * Dhossz * Vélszám.NextDouble
            Select Case Ecset.Color
                Case Color.Blue
                    Ecset.Color = Color.Aqua
                Case Else
                    Ecset.Color = Color.Blue
            End Select
        Loop
        PictureBox1.Invalidate()
    End Sub

    Private Sub Labirintus_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Labirintus.Click
        Const Méret As Single = 5
        Dim Sor, Oszlop As Integer
        Dim Vélszám As Random
        Vélszám = New Random
        Grafobj.Clear(Color.White)
        Ecset.Color = Color.Blue
        For Sor = 0 To Maxkoord Step 2 * Méret
            For Oszlop = 0 To Maxkoord Step 2 * Méret
                Grafobj.FillRectangle(Ecset, Sor, Oszlop, Méret, Méret)
                If Vélszám.Next(0, 2) = 0 Then
                    Grafobj.FillRectangle(Ecset, Sor + Méret, Oszlop, Méret, Méret)
                End If
                If Vélszám.Next(0, 2) = 0 Then
                    Grafobj.FillRectangle(Ecset, Sor, Oszlop + Méret, Méret, Méret)
                End If
            Next
        Next
        Ecset.Color = Color.Black
        PictureBox1.Invalidate()
    End Sub

    Private Sub Körök_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Körök.Click
        Const Db As Integer = 500        ' a körök száma
        Const MaxÁtmérő As Integer = 100 ' a legnagyobb kör átmérője
        Dim X, Y As Integer              ' a körök koordinátái
        Dim Átmérő As Integer            ' a körök átmérője
        Dim Szög As Integer              ' a színátmenet iránya (0-tól 360 fokig)
        Dim Szín1, Szín2 As Color        ' a színátmenet kezdő- és végső színe
        Dim I As Integer                 ' ciklusváltozó
        Dim Vélszám As Random            ' véletlenszámobjektum
        Dim Téglalap As Rectangle        ' téglalapobjektum a gradiensecset létrehozásához
        ' Gradiens- (színátmenetes) ecset:
        Dim Ecset As Drawing2D.LinearGradientBrush

        ' Létrehozzuk a véletlenszámobjektumot:
        Vélszám = New Random
        ' Kitöltjük a hátteret:
        Grafobj.Clear(Color.LightSkyBlue)
        ' Létrehozzuk a téglalapobjektumot (a színátmenet kezdő- és végpontját adja meg):
        Téglalap = New Rectangle()
        ' Beállítjuk a téglalap bal felső csúcsát:
        Téglalap.X = 0
        Téglalap.Y = 0
        ' A köröket megrajzoló ciklus:
        For I = 1 To Db
            ' Beállítjuk a téglalap magasságát és szélességét:
            Téglalap.Height = Vélszám.Next(1, MaxÁtmérő + 1)
            Téglalap.Width = Vélszám.Next(1, MaxÁtmérő + 1)
            ' Kiválasztjuk a kezdő- és végső színt:
            Szín1 = Color.FromArgb(255, Vélszám.Next(0, 256), Vélszám.Next(0, 256), Vélszám.Next(0, 256))
            Szín2 = Color.FromArgb(255, Vélszám.Next(0, 256), Vélszám.Next(0, 256), Vélszám.Next(0, 256))
            ' Megadjuk a színátmenet irányát:
            Szög = Vélszám.Next(0, 360)
            ' Létrehozzuk a gradiensecsetet:
            Ecset = New Drawing2D.LinearGradientBrush(Téglalap, Szín1, Szín2, Szög)
            ' Kiválasztjuk a kör helyét és átmérőjét:
            X = Vélszám.Next(0, Maxkoord - MaxÁtmérő)
            Y = Vélszám.Next(0, Maxkoord - MaxÁtmérő)
            Átmérő = Vélszám.Next(1, MaxÁtmérő + 1)
            ' Megrajzoljuka kört:
            Grafobj.FillEllipse(Ecset, X, Y, Átmérő, Átmérő)
            ' Töröljük az ecsetobjektumot:
            Ecset.Dispose()
            ' Frissítjük a képernyőt:
            PictureBox1.Invalidate()
        Next
    End Sub

    Private Sub Spirál_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Spirál.Click
        Const Fordulat = 30 ' a fordulatok száma
        Const D = 5         ' a két kör középpontjának távolsága
        Dim I, R As Integer
        ' Töröljük a rajzlapot (kitöltjük fehér színnel):
        Grafobj.Clear(Color.White)
        ' Beállítjuk a Toll méretét:
        Toll.Width = 1
        R = D ' az első kör sugara
        For I = 1 To Fordulat
            Toll.Color = Color.Red
            Grafobj.DrawArc(Toll, OrigóX - R, OrigóX - R, 2 * R, 2 * R, 0, -180)
            R += D
            Toll.Color = Color.Blue
            Grafobj.DrawArc(Toll, OrigóX + D - R, OrigóX - R, 2 * R, 2 * R, 0, 180)
            R += D
        Next
        PictureBox1.Invalidate()
    End Sub

    Private Sub Archimédesz_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Archimédesz.Click
        Const DT As Single = 0.01      ' lépésköz
        Const Fordulat As Single = 50  ' a fordulatok száma
        Dim X, Y As Single ' a pontok koordinátái
        Dim T As Single    ' paraméter
        Dim C As Single    ' az ívek távolságára jellemző paraméter
        ' Töröljük a rajzlapot (kitöltjük fehér színnel):
        Grafobj.Clear(Color.White)
        ' Beállítjuk az Ecset színét:
        Ecset.Color = Color.Blue
        C = InputBox("Add meg a távolságparamétert (0-40)!", "Távolság", "1")
        For T = 0 To Fordulat * 2 * Math.PI Step DT
            X = C * T * Math.Sin(T) + OrigóX
            Y = C * T * Math.Cos(T) + OrigóY
            Grafobj.FillRectangle(Ecset, X, Y, 1, 1)
        Next
        PictureBox1.Invalidate()
    End Sub

    Private Sub Spirográf_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Spirográf.Click
        Const R3 As Single = 300  ' a rögzített kör sugara
        Const DT As Single = 0.01 ' lépésköz
        Dim R1 As Single          ' a gördülő kör sugara
        Dim R2 As Single          ' a toll távolsága a gördülő kör középpontjától
        Dim T As Single           ' paraméter
        Dim X, Y As Integer
        Grafobj.Clear(Color.White)
        Ecset.Color = Color.Red
        R1 = InputBox("Írd be a gördülő kör sugarát!", "A gördülő kör sugara", "70")
        R2 = InputBox("Írd be a toll távolságát a kör középpontjától!", "A toll távolsága", "100")
        For T = 0 To 2 * R3 * Math.PI Step DT
            X = (R3 - R1) * Math.Cos(R1 * T / R3) + R2 * Math.Cos(T) + OrigóX
            Y = (R3 - R1) * Math.Sin(R1 * T / R3) + R2 * Math.Sin(T) + OrigóY
            Grafobj.FillRectangle(Ecset, X, Y, 2, 2)
        Next
        PictureBox1.Invalidate()
    End Sub



End Class
